🔖 [Table of Contents](../README.md) / [FAQ](README.md)

# How to Get Data from Other Tasks?

Tasks are usually be isolated from each other.

But it some cases, sharing data among tasks can be quite handy. Zrb doesn't support this mechanism out of the box, but you can make use `_ZRB_EXECUTION_ID` to achieve what you want.

See [this tutorial](../tutorials/getting-data-from-other-tasks.md) for more information.

🔖 [Table of Contents](../README.md) / [FAQ](README.md)
